@@ -5,7 +5,8 @@ import httpx
 from myst.auth.credentials import Credentials
 from myst.models.base_model import BaseModel
 from myst.models.exceptions import MystAPIError, MystClientError, UnauthenticatedError
-from myst.models.http_errors import ValidationError
+from myst.models.http_errors import HTTPValidationError
+from myst.settings import settings
 from myst.version import get_package_version
 
 RequestModelType = TypeVar("RequestModelType", bound=BaseModel)
@@ -15,24 +16,18 @@ ResponseModelType = TypeVar("ResponseModelType", bound=BaseModel)
 class Client:
     """HTTP client for interacting with the Myst API."""
 
-    API_HOST = "https://api.myst.ai"
     API_VERSION = "v1alpha2"
-
     USER_AGENT_PREFORMAT = "Myst/{api_version} PythonBindings/{package_version}"
 
-    # Increase default timeout, since it's insufficient for some longer inserts/retrievals.
-    API_TIMEOUT_SEC = 30
-
     def __init__(
-        self,
-        credentials: Optional[Credentials] = None,
-        timeout: int = API_TIMEOUT_SEC,
-        api_host: str = API_HOST,
+        self, credentials: Optional[Credentials] = None, timeout: Optional[int] = None, api_host: Optional[str] = None
     ):
         """A wrapper object providing convenient API access with credentials."""
         # Construct an httpx client so that we can reuse a single TCP connection and configuration.
         self._client = httpx.Client(
-            timeout=timeout, headers={"User-Agent": self.user_agent}, base_url=f"{api_host}/{self.API_VERSION}"
+            timeout=timeout or settings.API_TIMEOUT_SEC,
+            headers={"User-Agent": self.user_agent},
+            base_url=f"{api_host or settings.MYST_API_HOST}/{self.API_VERSION}",
         )
         self._credentials = credentials
 
@@ -101,7 +96,7 @@ class Client:
             return response_class.parse_raw(response.content)
         elif response.status_code == 422:
             # Special-case 422 validation errors.
-            raise MystClientError(ValidationError.parse_raw(response.content))
+            raise MystClientError(HTTPValidationError.parse_raw(response.content))
         elif 400 <= response.status_code < 500:
             # All other client errors.
             raise MystClientError(response)
