@@ -10,7 +10,7 @@ from myst.models.base_model import BaseModel
 class TimeSeriesInsertResult(BaseModel):
     """Time series insert result schema."""
 
-    object: Literal["Result"] = "Result"
+    object: Literal["NodeResult"] = "NodeResult"
     uuid: UUID
     create_time: Time
     type: Literal["TimeSeriesInsertResult"] = "TimeSeriesInsertResult"
