@@ -11,7 +11,7 @@ from myst.models.time_dataset import TimeDataset
 class TimeSeriesQueryResult(BaseModel):
     """Time series query result schema."""
 
-    object: Literal["Result"] = "Result"
+    object: Literal["NodeResult"] = "NodeResult"
     uuid: UUID
     create_time: Time
     type: Literal["TimeSeriesQueryResult"] = "TimeSeriesQueryResult"
