@@ -11,7 +11,4 @@ PACKAGE_NAME = "myst-alpha"
 
 def get_package_version() -> str:
     """Returns the package version."""
-    metadata = importlib_metadata.metadata(PACKAGE_NAME)  # type: ignore
-    version = metadata["Version"]
-
-    return version
+    return importlib_metadata.version(PACKAGE_NAME)
